==> RoughlyEnoughItems-4.1.8-unstable-sources.jar: me/shedaniel/rei/plugin/DefaultRecipeBookExclusionZones.java <==
/*
 * This file is licensed under the MIT License, part of Roughly Enough Items.
 * Copyright (c) 2018, 2019, 2020 shedaniel
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package me.shedaniel.rei.plugin;

import com.google.common.collect.Lists;
import me.shedaniel.math.Rectangle;
import me.shedaniel.rei.impl.ScreenHelper;
import me.shedaniel.rei.listeners.ContainerScreenHooks;
import net.minecraft.class_1729;
import net.minecraft.class_299;
import net.minecraft.class_310;
import net.minecraft.class_518;
import java.util.Collections;
import java.util.List;
import java.util.function.Supplier;

public class DefaultRecipeBookExclusionZones implements Supplier<List<Rectangle>> {
    
    @Override
    public List<Rectangle> get() {
        if (!class_310.method_1551().field_1724.method_3130().method_14887() || !(class_310.method_1551().field_1755 instanceof class_518) || !(ScreenHelper.getLastHandledScreen().method_17577() instanceof class_1729))
            return Collections.emptyList();
        ContainerScreenHooks screenHooks = ((ContainerScreenHooks) ScreenHelper.getLastHandledScreen());
        List<Rectangle> l = Lists.newArrayList(new Rectangle(screenHooks.rei_getContainerLeft() - 4 - 145, screenHooks.rei_getContainerTop(), 4 + 145 + 30, screenHooks.rei_getContainerHeight()));
        int size = class_299.method_1395((class_1729<?>) ScreenHelper.getLastHandledScreen().method_17577()).size();
        if (size > 0)
            l.add(new Rectangle(screenHooks.rei_getContainerLeft() - 4 - 145 - 30, screenHooks.rei_getContainerTop(), 30, size * 27));
        return l;
    }
    
}

==> RoughlyEnoughItems-4.1.12-unstable-sources.jar: me/shedaniel/rei/plugin/DefaultRecipeBookExclusionZones.java <==
/*
 * This file is licensed under the MIT License, part of Roughly Enough Items.
 * Copyright (c) 2018, 2019, 2020 shedaniel
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package me.shedaniel.rei.plugin;

import com.google.common.collect.Lists;
import me.shedaniel.math.Rectangle;
import me.shedaniel.rei.api.REIHelper;
import net.minecraft.class_1729;
import net.minecraft.class_299;
import net.minecraft.class_310;
import net.minecraft.class_465;
import net.minecraft.class_518;
import java.util.Collections;
import java.util.List;
import java.util.function.Supplier;

public class DefaultRecipeBookExclusionZones implements Supplier<List<Rectangle>> {
    
    @Override
    public List<Rectangle> get() {
        if (!class_310.method_1551().field_1724.method_3130().method_14887() || !(class_310.method_1551().field_1755 instanceof class_518) || !(REIHelper.getInstance().getPreviousHandledScreen().method_17577() instanceof class_1729))
            return Collections.emptyList();
        class_465<?> handledScreen = REIHelper.getInstance().getPreviousHandledScreen();
        List<Rectangle> l = Lists.newArrayList(new Rectangle(handledScreen.field_2776 - 4 - 145, handledScreen.field_2800, 4 + 145 + 30, handledScreen.field_2779));
        int size = class_299.method_1395((class_1729<?>) REIHelper.getInstance().getPreviousHandledScreen().method_17577()).size();
        if (size > 0)
            l.add(new Rectangle(handledScreen.field_2776 - 4 - 145 - 30, handledScreen.field_2800, 30, size * 27));
        return l;
    }
    
}
